Predict method for seinfitR objects
# S3 method for seinfitR
predict(object, newdata = NULL, ...)A data frame with the independent variable and the corresponding predicted values.
An object of class seinfitR (output from seinfitR()).
Optional. A data frame containing the independent variable for which predictions should be made. If not provided, predictions are made for the original data.
currently unused.
This function generates predictions based on a fitted Seinhorst model.